pub struct RapidTriggerState { /* private fields */ }Implementations
Sourceimpl RapidTriggerState
impl RapidTriggerState
pub const fn new() -> Self
Sourcepub fn update(
&mut self,
val: u16,
press_dist: u16,
release_dist: u16,
top_deadzone: u16,
) -> Option<bool>
pub fn update( &mut self, val: u16, press_dist: u16, release_dist: u16, top_deadzone: u16, ) -> Option<bool>
Updates the state with a new travel distance and returns whether the key state changed.
Arguments
val: Physical travel distance in 0.01mm units (e.g., 0-400 for 0-4.0mm).press_dist: Threshold to trigger press when moving down (in 0.01mm).release_dist: Threshold to trigger release when moving up (in 0.01mm).top_deadzone: Initial travel distance required before activating rapid trigger (in 0.01mm).